@@ -1,19 +1,18 @@
 // Copyright 2011-2016 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "sord_config.h" // IWYU pragma: keep
 #include "sord_internal.h"
 
-#include "serd/serd.h"
-#include "sord/sord.h"
+#include <serd/serd.h>
+#include <sord/sord.h>
 
 #define ZIX_HASH_KEY_TYPE SordNode
 #define ZIX_HASH_RECORD_TYPE SordNode
 #define ZIX_HASH_SEARCH_DATA_TYPE SordWorld
-#include "zix/btree.h"
-#include "zix/digest.h"
-#include "zix/hash.h"
-#include "zix/status.h"
+#include <zix/btree.h>
+#include <zix/digest.h>
+#include <zix/hash.h>
+#include <zix/status.h>
 
 #include <assert.h>
 #include <stdarg.h>
@@ -170,10 +169,12 @@ sord_node_record_key(const SordNode* n)
 static size_t
 sord_node_hash(const SordNode* const node)
 {
+  const size_t head = node->node.type;
+
   size_t hash = 0U;
 
-  hash = zix_digest(hash, node->node.buf, node->node.n_bytes);
-  hash = zix_digest(hash, &node->node.type, sizeof(node->node.type));
+  hash = zix_digest(hash, (const uint8_t*)node->node.buf, node->node.n_bytes);
+  hash = zix_digest(hash, &head, sizeof(head));
   if (node->node.type == SERD_LITERAL) {
     hash = zix_digest(hash, &node->meta.lit, sizeof(node->meta.lit));
   }
@@ -209,8 +210,7 @@ sord_node_create(const SordNode* const node)
   return copy;
 }
 
-SORD_LOG_FUNC(3, 4)
-static void
+SORD_LOG_FUNC(3, 4) static void
 error(SordWorld* world, SerdStatus st, const char* fmt, ...)
 {
   va_list args;
@@ -526,7 +526,7 @@ sord_iter_scan_next(SordIter* iter)
     return true;
   }
 
-  const SordNode** key;
+  const SordNode** key = NULL;
   if (!iter->end) {
     switch (iter->mode) {
     case ALL:
@@ -635,8 +635,8 @@ sord_best_index(SordModel*     sord,
 {
   const bool graph_search = (pat[TUP_G] != 0);
 
-  const unsigned sig = (pat[0] ? 1 : 0) * 0x100 + (pat[1] ? 1 : 0) * 0x010 +
-                       (pat[2] ? 1 : 0) * 0x001;
+  const unsigned sig = (pat[0] ? 1 : 0) * 0x100U + (pat[1] ? 1 : 0) * 0x010U +
+                       (pat[2] ? 1 : 0) * 0x001U;
 
   SordOrder good[2] = {(SordOrder)-1, (SordOrder)-1};
 
@@ -717,7 +717,7 @@ sord_new(SordWorld* world, unsigned indices, bool graphs)
     const int* const ordering   = orderings[i];
     const int* const g_ordering = orderings[i + (NUM_ORDERS / 2)];
 
-    if (indices & (1 << i)) {
+    if (indices & (1U << i)) {
       model->indices[i] =
         zix_btree_new(NULL, sord_quad_compare, (void*)ordering);
       if (graphs) {
@@ -867,8 +867,8 @@ sord_find(SordModel* model, const SordQuad pat)
     return sord_begin(model);
   }
 
-  SearchMode      mode;
-  int             n_prefix;
+  SearchMode      mode        = ALL;
+  int             n_prefix    = 0;
   const SordOrder index_order = sord_best_index(model, pat, &mode, &n_prefix);
 
   SORD_FIND_LOG("Find " TUP_FMT "  index=%s  mode=%u  n_prefix=%d\n",
@@ -935,7 +935,7 @@ sord_get(SordModel*      model,
          const SordNode* o,
          const SordNode* g)
 {
-  if ((bool)s + (bool)p + (bool)o != 2) {
+  if (!!s + !!p + !!o != 2) {
     return NULL;
   }
 
